<?php
declare(strict_types=1);

namespace Catequil\Barcode\Handler;

use Catequil\Barcode\Service\BarcodeServiceInterface;
use Catequil\Core\Mapping\Route;
use Laminas\Diactoros\Response\JsonResponse;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class GetSku
 *
 * @package Catequil\Barcode\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-barcode
 */
#[Route('/api/barcode/sku/:barcode', 'GET', 'barcode.get-sku')]
final class GetSkuFromBarcode implements RequestHandlerInterface
{
    private BarcodeServiceInterface $barcodes;

    /**
     * @param BarcodeServiceInterface $barcodes
     */
    public function __construct(BarcodeServiceInterface $barcodes)
    {
        $this->barcodes = $barcodes;
    }

    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        return new JsonResponse(
            $this->barcodes->findSku(
                $request->getAttribute('barcode')
            )
        );
    }
}
