<?php
declare(strict_types=1);

namespace Catequil\Barcode\Service;

use Catequil\Barcode\Model\Barcode;
use Catequil\Barcode\Model\BarcodeInterface;
use Catequil\Barcode\Repository\BarcodeRepository;
use Doctrine\ORM\EntityManagerInterface;

/**
 * Class BarcodeService
 *
 * @package Catequil\Barcode\Service
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-barcode
 */
final class BarcodeService implements BarcodeServiceInterface
{
    private EntityManagerInterface $em;

    /**
     * @param EntityManagerInterface $em
     */
    public function __construct(EntityManagerInterface $em)
    {
        $this->em = $em;
    }

    public function find(string $barcode): ?BarcodeInterface
    {
        /** @var BarcodeRepository $repo */
        $repo = $this->em->getRepository(Barcode::class);
        return $repo->findByBarcode($barcode);
    }

    public function findSku(string $barcode): ?string
    {
        $barcode = $this->find($barcode);
        return $barcode?->getSku();
    }
}
